==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/github/StaleOptions.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) Options for `Stale`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.772Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.StaleOptions")
@software.amazon.jsii.Jsii.Proxy(StaleOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface StaleOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) How to handle stale issues.
     * <p>
     * Default: - By default, stale issues with no activity will be marked as
     * stale after 60 days and closed within 7 days.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.StaleBehavior getIssues() {
        return null;
    }

    /**
     * (experimental) How to handle stale pull requests.
     * <p>
     * Default: - By default, pull requests with no activity will be marked as
     * stale after 14 days and closed within 2 days with relevant comments.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.StaleBehavior getPullRequest() {
        return null;
    }

    /**
     * (experimental) Github Runner selection labels.
     * <p>
     * Default: ["ubuntu-latest"]
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getRunsOn() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link StaleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link StaleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<StaleOptions> {
        io.github.cdklabs.projen.github.StaleBehavior issues;
        io.github.cdklabs.projen.github.StaleBehavior pullRequest;
        java.util.List<java.lang.String> runsOn;

        /**
         * Sets the value of {@link StaleOptions#getIssues}
         * @param issues How to handle stale issues.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder issues(io.github.cdklabs.projen.github.StaleBehavior issues) {
            this.issues = issues;
            return this;
        }

        /**
         * Sets the value of {@link StaleOptions#getPullRequest}
         * @param pullRequest How to handle stale pull requests.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pullRequest(io.github.cdklabs.projen.github.StaleBehavior pullRequest) {
            this.pullRequest = pullRequest;
            return this;
        }

        /**
         * Sets the value of {@link StaleOptions#getRunsOn}
         * @param runsOn Github Runner selection labels.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder runsOn(java.util.List<java.lang.String> runsOn) {
            this.runsOn = runsOn;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link StaleOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public StaleOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link StaleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements StaleOptions {
        private final io.github.cdklabs.projen.github.StaleBehavior issues;
        private final io.github.cdklabs.projen.github.StaleBehavior pullRequest;
        private final java.util.List<java.lang.String> runsOn;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.issues = software.amazon.jsii.Kernel.get(this, "issues", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.StaleBehavior.class));
            this.pullRequest = software.amazon.jsii.Kernel.get(this, "pullRequest", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.StaleBehavior.class));
            this.runsOn = software.amazon.jsii.Kernel.get(this, "runsOn", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.issues = builder.issues;
            this.pullRequest = builder.pullRequest;
            this.runsOn = builder.runsOn;
        }

        @Override
        public final io.github.cdklabs.projen.github.StaleBehavior getIssues() {
            return this.issues;
        }

        @Override
        public final io.github.cdklabs.projen.github.StaleBehavior getPullRequest() {
            return this.pullRequest;
        }

        @Override
        public final java.util.List<java.lang.String> getRunsOn() {
            return this.runsOn;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getIssues() != null) {
                data.set("issues", om.valueToTree(this.getIssues()));
            }
            if (this.getPullRequest() != null) {
                data.set("pullRequest", om.valueToTree(this.getPullRequest()));
            }
            if (this.getRunsOn() != null) {
                data.set("runsOn", om.valueToTree(this.getRunsOn()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.StaleOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            StaleOptions.Jsii$Proxy that = (StaleOptions.Jsii$Proxy) o;

            if (this.issues != null ? !this.issues.equals(that.issues) : that.issues != null) return false;
            if (this.pullRequest != null ? !this.pullRequest.equals(that.pullRequest) : that.pullRequest != null) return false;
            return this.runsOn != null ? this.runsOn.equals(that.runsOn) : that.runsOn == null;
        }

        @Override
        public final int hashCode() {
            int result = this.issues != null ? this.issues.hashCode() : 0;
            result = 31 * result + (this.pullRequest != null ? this.pullRequest.hashCode() : 0);
            result = 31 * result + (this.runsOn != null ? this.runsOn.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/github/StaleOptions.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) Options for <code>Stale</code>.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.437Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.StaleOptions")
@software.amazon.jsii.Jsii.Proxy(StaleOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface StaleOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) How to handle stale issues.
     * <p>
     * Default: - By default, stale issues with no activity will be marked as
     * stale after 60 days and closed within 7 days.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.StaleBehavior getIssues() {
        return null;
    }

    /**
     * (experimental) How to handle stale pull requests.
     * <p>
     * Default: - By default, pull requests with no activity will be marked as
     * stale after 14 days and closed within 2 days with relevant comments.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.StaleBehavior getPullRequest() {
        return null;
    }

    /**
     * (experimental) Github Runner selection labels.
     * <p>
     * Default: ["ubuntu-latest"]
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getRunsOn() {
        return null;
    }

    /**
     * (experimental) Github Runner Group selection options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.GroupRunnerOptions getRunsOnGroup() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link StaleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link StaleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<StaleOptions> {
        io.github.cdklabs.projen.github.StaleBehavior issues;
        io.github.cdklabs.projen.github.StaleBehavior pullRequest;
        java.util.List<java.lang.String> runsOn;
        io.github.cdklabs.projen.GroupRunnerOptions runsOnGroup;

        /**
         * Sets the value of {@link StaleOptions#getIssues}
         * @param issues How to handle stale issues.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder issues(io.github.cdklabs.projen.github.StaleBehavior issues) {
            this.issues = issues;
            return this;
        }

        /**
         * Sets the value of {@link StaleOptions#getPullRequest}
         * @param pullRequest How to handle stale pull requests.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pullRequest(io.github.cdklabs.projen.github.StaleBehavior pullRequest) {
            this.pullRequest = pullRequest;
            return this;
        }

        /**
         * Sets the value of {@link StaleOptions#getRunsOn}
         * @param runsOn Github Runner selection labels.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder runsOn(java.util.List<java.lang.String> runsOn) {
            this.runsOn = runsOn;
            return this;
        }

        /**
         * Sets the value of {@link StaleOptions#getRunsOnGroup}
         * @param runsOnGroup Github Runner Group selection options.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder runsOnGroup(io.github.cdklabs.projen.GroupRunnerOptions runsOnGroup) {
            this.runsOnGroup = runsOnGroup;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link StaleOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public StaleOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link StaleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements StaleOptions {
        private final io.github.cdklabs.projen.github.StaleBehavior issues;
        private final io.github.cdklabs.projen.github.StaleBehavior pullRequest;
        private final java.util.List<java.lang.String> runsOn;
        private final io.github.cdklabs.projen.GroupRunnerOptions runsOnGroup;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.issues = software.amazon.jsii.Kernel.get(this, "issues", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.StaleBehavior.class));
            this.pullRequest = software.amazon.jsii.Kernel.get(this, "pullRequest", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.StaleBehavior.class));
            this.runsOn = software.amazon.jsii.Kernel.get(this, "runsOn", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.runsOnGroup = software.amazon.jsii.Kernel.get(this, "runsOnGroup", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.GroupRunnerOptions.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.issues = builder.issues;
            this.pullRequest = builder.pullRequest;
            this.runsOn = builder.runsOn;
            this.runsOnGroup = builder.runsOnGroup;
        }

        @Override
        public final io.github.cdklabs.projen.github.StaleBehavior getIssues() {
            return this.issues;
        }

        @Override
        public final io.github.cdklabs.projen.github.StaleBehavior getPullRequest() {
            return this.pullRequest;
        }

        @Override
        public final java.util.List<java.lang.String> getRunsOn() {
            return this.runsOn;
        }

        @Override
        public final io.github.cdklabs.projen.GroupRunnerOptions getRunsOnGroup() {
            return this.runsOnGroup;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getIssues() != null) {
                data.set("issues", om.valueToTree(this.getIssues()));
            }
            if (this.getPullRequest() != null) {
                data.set("pullRequest", om.valueToTree(this.getPullRequest()));
            }
            if (this.getRunsOn() != null) {
                data.set("runsOn", om.valueToTree(this.getRunsOn()));
            }
            if (this.getRunsOnGroup() != null) {
                data.set("runsOnGroup", om.valueToTree(this.getRunsOnGroup()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.StaleOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            StaleOptions.Jsii$Proxy that = (StaleOptions.Jsii$Proxy) o;

            if (this.issues != null ? !this.issues.equals(that.issues) : that.issues != null) return false;
            if (this.pullRequest != null ? !this.pullRequest.equals(that.pullRequest) : that.pullRequest != null) return false;
            if (this.runsOn != null ? !this.runsOn.equals(that.runsOn) : that.runsOn != null) return false;
            return this.runsOnGroup != null ? this.runsOnGroup.equals(that.runsOnGroup) : that.runsOnGroup == null;
        }

        @Override
        public final int hashCode() {
            int result = this.issues != null ? this.issues.hashCode() : 0;
            result = 31 * result + (this.pullRequest != null ? this.pullRequest.hashCode() : 0);
            result = 31 * result + (this.runsOn != null ? this.runsOn.hashCode() : 0);
            result = 31 * result + (this.runsOnGroup != null ? this.runsOnGroup.hashCode() : 0);
            return result;
        }
    }
}
